@@ -1,18 +1,22 @@
-__version__ = "0.9.0"
+__version__ = "1.4.9"
 
+from .api import close, render, save_html, show, stacked
 from .core import Maidr
 from .core.enum import PlotType
 from .patch import (
     barplot,
     boxplot,
+    candlestick,
     clear,
     heatmap,
     highlight,
     histogram,
     lineplot,
     scatterplot,
+    regplot,
+    kdeplot,
+    mplfinance,
 )
-from .api import close, render, save_html, show, stacked
 
 __all__ = [
     "close",
