@@ -5,12 +5,13 @@ class MaidrKey(str, Enum):
     # Maidr info keys.
     ID = "id"
     ORIENTATION = "orientation"
-    SELECTOR = "selector"
+    SELECTOR = "selectors"
     TYPE = "type"
 
     # Plot data keys.
     AXES = "axes"
     DATA = "data"
+    POINTS = "points"
     LEVEL = "level"
     X = "x"
     Y = "y"
@@ -22,20 +23,22 @@ class MaidrKey(str, Enum):
     TITLE = "title"
 
     # Box plot keys.
-    LOWER_OUTLIER = "lower_outlier"
+    LOWER_OUTLIER = "lowerOutliers"
     MIN = "min"
     MAX = "max"
     Q1 = "q1"
     Q2 = "q2"
     Q3 = "q3"
-    UPPER_OUTLIER = "upper_outlier"
+    UPPER_OUTLIER = "upperOutliers"
+    IQ = "iq"
+    MEDIAN = "median"
 
     # Grouped bar and heatmap plot keys.
     FILL = "fill"
     LABELS = "labels"
 
     # Histogram plot keys.
-    X_MIN = "xmin"
-    X_MAX = "xmax"
-    Y_MIN = "ymin"
-    Y_MAX = "ymax"
+    X_MIN = "xMin"
+    X_MAX = "xMax"
+    Y_MIN = "yMin"
+    Y_MAX = "yMax"
