@@ -1,7 +1,6 @@
 from __future__ import annotations
 
 import numpy.ma as ma
-
 from matplotlib.axes import Axes
 from matplotlib.collections import PathCollection
 
@@ -15,8 +14,8 @@ class ScatterPlot(MaidrPlot, CollectionExtractorMixin):
     def __init__(self, ax: Axes) -> None:
         super().__init__(ax, PlotType.SCATTER)
 
-    def _get_selector(self) -> str:
-        return "g[maidr='true'] > use"
+    def _get_selector(self) -> str | list[str]:
+        return ["g[maidr='true'] > g > use"]
 
     def _extract_plot_data(self) -> list[dict]:
         plot = self.extract_collection(self.ax, PathCollection)
