@@ -1,5 +1,6 @@
 from __future__ import annotations
 
+import warnings
 from typing import Any
 
 from maidr.core.context_manager import ContextManager
@@ -7,6 +8,9 @@ from maidr.core.figure_manager import FigureManager
 
 
 def common(plot_type, wrapped, _, args, kwargs) -> Any:
+    # Suppress warnings not to confuse screen-reader users
+    warnings.filterwarnings("ignore")
+
     # Don't proceed if the call is made internally by the patched function.
     if ContextManager.is_internal_context():
         return wrapped(*args, **kwargs)
@@ -18,6 +22,7 @@ def common(plot_type, wrapped, _, args, kwargs) -> Any:
 
     # Extract the data points for MAIDR from the plot.
     ax = FigureManager.get_axes(plot)
-    FigureManager.create_maidr(ax, plot_type)
+    kwargs.pop("ax", None)
+    FigureManager.create_maidr(ax, plot_type, **kwargs)
 
     return plot
